@@ -1,11 +1,11 @@
-#[cfg(windows)]
-use windows_sys::Win32::UI::WindowsAndMessaging::*;
-#[cfg(windows)]
-use windows_sys::Win32::Foundation::PSTR;
-#[cfg(linux)]
-use gtk::prelude::*;
 #[cfg(linux)]
 use gtk::gdk::WindowTypeHint;
+#[cfg(linux)]
+use gtk::prelude::*;
+#[cfg(windows)]
+use windows_sys::Win32::Foundation::PSTR;
+#[cfg(windows)]
+use windows_sys::Win32::UI::WindowsAndMessaging::*;
 
 // Default
 
@@ -30,7 +30,7 @@ pub const DEFAULT_WINDOW_Y: i32 = 500;
 pub const DEFAULT_WINDOW_Y: i32 = 1280;
 
 #[cfg(windows)]
-pub const DEFAULT_WINDOW_WINDOW_CLASS: PSTR = b"window\0".as_ptr() as _;
+pub const DEFAULT_WINDOW_CLASS: PSTR = b"window\0".as_ptr() as _;
 #[cfg(linux)]
 pub const DEFAULT_WINDOW_CLASS: i32 = 0;
 
@@ -83,8 +83,6 @@ pub const DIALOGSTYLE_INFO: MESSAGEBOX_STYLE = 64u32;
 #[cfg(linux)]
 pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Info;
 
-
-
 #[cfg(windows)]
 pub const DIALOGSTYLE_QUESTION: MESSAGEBOX_STYLE = 32u32;
 #[cfg(linux)]
@@ -157,4 +155,4 @@ pub const WINDOWSTYLE_VSCROLL: WindowTypeHint = gtk::gdk::WindowTypeHint::Deskto
 #[cfg(windows)]
 pub const WINDOWSTYLE_SIZEBOX: WINDOW_STYLE = 262144u32;
 #[cfg(linux)]
-pub const WINDOWSTYLE_SIZEBOX: WindowTypeHint = gtk::gdk::WindowTypeHint::Desktop;
\ No newline at end of file
+pub const WINDOWSTYLE_SIZEBOX: WindowTypeHint = gtk::gdk::WindowTypeHint::Desktop;
