@@ -2,14 +2,31 @@ use windows_sys::Win32::UI::WindowsAndMessaging::MESSAGEBOX_STYLE;
 
 pub struct MessageBox {
     pub title: String,
-    pub message: String
+    pub message: String,
 }
 
 impl MessageBox {
+
+    ///
+    /// Create a new dialog
+    ///
+    pub fn new(title: String, message: String) -> Self {
+        Self {
+            title,
+            message
+        }
+    }
+
+    ///
+    /// Returns the title
+    ///
     pub fn get_title(&self) -> &str {
         &self.title
     }
 
+    ///
+    /// Returns the message
+    ///
     pub fn get_message(&self) -> &str {
         &self.message
     }
@@ -25,19 +42,21 @@ impl MessageBox {
     /// - DIALOGSTYLE_EXCLAMATION
     /// - DIALOGSTYLE_ERROR
     ///```
-    /// use windows_sys::Win32::UI::WindowsAndMessaging::*;
     /// use nxui::messagebox;
     /// use nxui::NativesAndMessaging::*;
     ///
-    /// //
-    ///
     /// fn main() {
     ///     let msg_box = messagebox::MessageBox { title: "This is a test".to_string().parse().unwrap(), message: "Hello World".to_string().parse().unwrap() };
     ///     msg_box.show(BUTTONSTYLE_OK,DIALOGSTYLE_INFO,DIALOGHINT_MODAL);
     /// }
     /// ```
     #[cfg(windows)]
-    pub fn show(&self,button_type: MESSAGEBOX_STYLE,dialog_style: MESSAGEBOX_STYLE,window_style: u64) {
+    pub fn show(
+        &self,
+        button_type: MESSAGEBOX_STYLE,
+        dialog_style: MESSAGEBOX_STYLE,
+        window_style: u64,
+    ) {
         use windows_sys::{
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
@@ -46,18 +65,28 @@ impl MessageBox {
             SetEvent(event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-            MessageBoxA(window_style.try_into().unwrap(), self.message.as_ptr(), self.title.as_ptr(), dialog_style|button_type);
+            MessageBoxA(
+                window_style.try_into().unwrap(),
+                self.message.as_ptr(),
+                self.title.as_ptr(),
+                dialog_style | button_type,
+            );
         }
     }
     #[cfg(linux)]
-    pub fn show(&self,button_type: ButtonsType,dialog_style: MessageType,window_style: DialogFlags) {
+    pub fn show(
+        &self,
+        button_type: ButtonsType,
+        dialog_style: MessageType,
+        window_style: DialogFlags,
+    ) {
         use gtk::prelude::*;
         let dialog = gtk::MessageDialog::new(
             Some(&window_),
             window_style,
             dialog_style,
             button_type,
-            &message
+            &message,
         );
         dialog.run();
         dialog.destroy();
