@@ -5,18 +5,86 @@ use windows_sys::{
 
 #[cfg(windows)]
 pub struct Window {
-    pub classname: PSTR,
+    pub windowclass: PSTR,
     pub title: String,
     pub width: i32,
     pub height: i32,
     pub x: i32,
-    pub y: i32
+    pub y: i32,
 }
 
 impl Window {
+
+    ///
+    /// Create a new window
+    ///
+    pub fn new(windowclass: PSTR, title: String, width: i32, height: i32, x: i32, y: i32) -> Self {
+        Self {
+            windowclass,
+            title,
+            width,
+            height,
+            x,
+            y,
+        }
+    }
+
+    ///
+    /// Returns the title
+    ///
+    pub fn get_title(self) -> String {
+        self.title
+    }
+
+    ///
+    /// Returns the width value.
+    ///
+    pub fn get_width(self) -> i32 {
+        self.width
+    }
+
+    ///
+    /// Returns the height value.
+    ///
+    pub fn get_height(self) -> i32 {
+        self.height
+    }
+
+    ///
+    /// Returns the x value.
+    ///
+    pub fn get_x_pos(self) -> i32 {
+        self.x
+    }
+
+    ///
+    /// Returns the y value.
+    ///
+    pub fn get_y_pos(self) -> i32 {
+        self.y
+    }
+
     #[cfg(windows)]
-    pub fn show(&self,window_style: WINDOW_STYLE,application_id: &str) {
-        extern "system" fn wndproc(window: HWND, message: u32, wparam: WPARAM, lparam: LPARAM) -> LRESULT {
+    ///
+    /// Display the window
+    ///
+    /// # Examples
+    /// ```
+    /// use nxui::{messagebox, window};
+    /// use nxui::NativesAndMessaging::*;
+    ///
+    /// fn main() {
+    ///     let win = nxui::window::Window { windowclass: DEFAULT_WINDOW_WINDOW_CLASS, title: "Hello World".to_string(), width: DEFAULT_WINDOW_WIDTH, height: DEFAULT_WINDOW_HEIGHT, x: DEFAULT_WINDOW_X, y: DEFAULT_WINDOW_Y };
+    ///     win.show(WINDOWSTYLE_OVERLAPPED,"io.github.lattesyobon.nxui");
+    /// }
+    /// ```
+    pub fn show(&self, window_style: WINDOW_STYLE, _application_id: &str) {
+        extern "system" fn wndproc(
+            window: HWND,
+            message: u32,
+            wparam: WPARAM,
+            lparam: LPARAM,
+        ) -> LRESULT {
             unsafe {
                 match message as u32 {
                     WM_PAINT => {
@@ -40,7 +108,7 @@ impl Window {
             let wc = WNDCLASSA {
                 hCursor: LoadCursorW(0, IDC_ARROW),
                 hInstance: instance,
-                lpszClassName: self.classname,
+                lpszClassName: self.windowclass,
                 style: CS_HREDRAW | CS_VREDRAW,
                 lpfnWndProc: Some(wndproc),
                 cbClsExtra: 0,
@@ -55,7 +123,7 @@ impl Window {
 
             CreateWindowExA(
                 0,
-                self.classname,
+                self.windowclass,
                 self.title.as_ptr() as _,
                 WS_VISIBLE | window_style,
                 CW_USEDEFAULT,
@@ -77,7 +145,7 @@ impl Window {
     }
 
     #[cfg(linux)]
-    pub fn show(&self,window_style: WINDOW_STYLE,application_id: &str) {
+    pub fn show(&self, window_style: WINDOW_STYLE, application_id: &str) {
         use gtk::prelude::*;
 
         fn build_ui(application: &gtk::Application) {
@@ -91,11 +159,10 @@ impl Window {
             window.show_all();
         }
 
-        let application =
-            gtk::Application::new(Some(application_id), Default::default());
+        let application = gtk::Application::new(Some(application_id), Default::default());
 
         application.connect_activate(build_ui);
 
         application.run();
     }
-}
\ No newline at end of file
+}
